import { TIngredients } from '@/types/TIngredients'
import styles from './BuildControls.module.css'
import BuildControl from './BuildControl/BuildControl'
import { TIngredientNames } from '@/types/TIngredientNames'

type Props = {
    ingredients: TIngredients
    price: number
    ingredientAdded: (type: TIngredientNames) => void;
    ingredientRemoved: (type: TIngredientNames) => void;
}

const BuildControls = ({ingredients, price, ingredientAdded, ingredientRemoved}: Props) => {
    return (
        <div className={styles.BuildControls}>
            <p>Current Price: <strong>{price} ₸</strong></p>
            {Object.keys(ingredients)
            .map(ingType => {
                return <BuildControl 
                    key={ingType} 
                    type={ingType as keyof typeof ingredients} 
                    added={() => ingredientAdded(ingType as keyof typeof ingredients)}
                    removed={() => ingredientRemoved(ingType as keyof typeof ingredients)}
                    disabled={!!ingredients[ingType as keyof typeof ingredients]}
                />
            })
            }
        </div>
    )
}

export default BuildControls